==> kubernetes-model-1.0.60-sources.jar: io/fabric8/kubernetes/api/model/extensions/JobSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Integer;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface JobSpecFluent<A extends JobSpecFluent<A>> extends Fluent<A>{


    public Long getActiveDeadlineSeconds();
    public A withActiveDeadlineSeconds(Long activeDeadlineSeconds);
    public Boolean isAutoSelector();
    public A withAutoSelector(Boolean autoSelector);
    public Integer getCompletions();
    public A withCompletions(Integer completions);
    public Integer getParallelism();
    public A withParallelism(Integer parallelism);
    public io.fabric8.kubernetes.api.model.extensions.LabelSelector getSelector();
    public A withSelector(io.fabric8.kubernetes.api.model.extensions.LabelSelector selector);
    public JobSpecFluent.ExtensionsSelectorNested<A> withNewExtensionsSelector();
    public JobSpecFluent.ExtensionsSelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    public JobSpecFluent.ExtensionsSelectorNested<A> editExtensionsSelector();
    public JobSpecFluent.ExtensionsSelectorNested<A> editOrNewSelector();
    public JobSpecFluent.ExtensionsSelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    public PodTemplateSpec getTemplate();
    public A withTemplate(PodTemplateSpec template);
    public JobSpecFluent.TemplateNested<A> withNewTemplate();
    public JobSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public JobSpecFluent.TemplateNested<A> editTemplate();
    public JobSpecFluent.TemplateNested<A> editOrNewTemplate();
    public JobSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);

    public interface ExtensionsSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.extensions.LabelSelectorFluent<JobSpecFluent.ExtensionsSelectorNested<N>>{

        
    public N and();    public N endExtensionsSelector();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<JobSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/extensions/JobSpecFluent.java <==
package io.fabric8.kubernetes.api.model.extensions;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Integer;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.PodTemplateSpecBuilder;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.PodTemplateSpecFluent;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface JobSpecFluent<A extends JobSpecFluent<A>> extends Fluent<A>{


    public Long getActiveDeadlineSeconds();
    public A withActiveDeadlineSeconds(Long activeDeadlineSeconds);
    public Boolean isAutoSelector();
    public A withAutoSelector(Boolean autoSelector);
    public Integer getCompletions();
    public A withCompletions(Integer completions);
    public Integer getParallelism();
    public A withParallelism(Integer parallelism);
    public io.fabric8.kubernetes.api.model.extensions.LabelSelector getSelector();
    public A withSelector(io.fabric8.kubernetes.api.model.extensions.LabelSelector selector);
    public JobSpecFluent.SelectorNested<A> withNewSelector();
    public JobSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    public JobSpecFluent.SelectorNested<A> editSelector();
    public JobSpecFluent.SelectorNested<A> editOrNewSelector();
    public JobSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.extensions.LabelSelector item);
    public PodTemplateSpec getTemplate();
    public A withTemplate(PodTemplateSpec template);
    public JobSpecFluent.TemplateNested<A> withNewTemplate();
    public JobSpecFluent.TemplateNested<A> withNewTemplateLike(PodTemplateSpec item);
    public JobSpecFluent.TemplateNested<A> editTemplate();
    public JobSpecFluent.TemplateNested<A> editOrNewTemplate();
    public JobSpecFluent.TemplateNested<A> editOrNewTemplateLike(PodTemplateSpec item);

    public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.extensions.LabelSelectorFluent<JobSpecFluent.SelectorNested<N>>{

        
    public N and();    public N endSelector();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateSpecFluent<JobSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}
